# djangocms-pai-custom-elements

Django-cms HTML custom elements app


## Description

A longer description of your project goes here...


## Note

This project has been set up using PyScaffold 3.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
